@@ -1,9 +1,10 @@
-# modelfit function to calc AIC and BIC statistics post estimation
-# Joseph M. Hilbe 12January, 2010
+# AIC and BIC statistics following glm, glm.nb, nbinomial
+# Joseph Hilbe, Modeling Count Data, Cambridge Univ Press
+# version 2  13 Aug, 2014. Amend xvars line
 modelfit  <- function(x)  {
 obs    <- x$df.null + 1
 aic    <- x$aic
-xvars  <- x$rank
+xvars  <- x$df.null - x$df.residual + 1
 rdof   <- x$df.residual
 aic_n  <- aic/obs
 ll     <- xvars - aic/2
